@@ -137,7 +137,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -153,45 +153,45 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class FargateToS3(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-s3.FargateToS3",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
         bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param bucket_arn_environment_variable_name: Optional Name for the container environment variable set to the bucket ARN. Default: - S3_BUCKET_ARN
         :param bucket_environment_variable_name: Optional Name for the container environment variable set to the bucket name. Default: - S3_BUCKET_NAME
         :param bucket_permissions: Optional bucket permissions to grant to the Fargate service. One or more of the following may be specified: "Delete", "Read", "Write". Default: - [ "Read", "Write" ]
@@ -211,31 +211,7 @@ class FargateToS3(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An S3 Interface endpoint will be included in this VPC. Default: - none
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                bucket_environment_variable_name: typing.Optional[builtins.str] = None,
-                bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5a872e0ea19151374d44819836b5422ed13b1d3eaaf460a209a1f9a4e784e646)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToS3Props(
@@ -263,33 +239,33 @@ class FargateToS3(
 
     @builtins.property
     @jsii.member(jsii_name="container")
-    def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
-        return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
+    def container(self) -> _aws_cdk_aws_ecs_ceddda9d.ContainerDefinition:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition, jsii.get(self, "container"))
 
     @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
-    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
-        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+    def s3_bucket_interface(self) -> _aws_cdk_aws_s3_ceddda9d.IBucket:
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.IBucket, jsii.get(self, "s3BucketInterface"))
 
     @builtins.property
     @jsii.member(jsii_name="service")
-    def service(self) -> aws_cdk.aws_ecs.FargateService:
-        return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
+    def service(self) -> _aws_cdk_aws_ecs_ceddda9d.FargateService:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.FargateService, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
     @builtins.property
     @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
+    def s3_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3Bucket"))
 
     @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
-    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
+    def s3_logging_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3LoggingBucket"))
 
 
 @jsii.data_type(
@@ -324,23 +300,23 @@ class FargateToS3Props:
         bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_environment_variable_name: typing.Optional[builtins.str] = None,
         bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param bucket_arn_environment_variable_name: Optional Name for the container environment variable set to the bucket ARN. Default: - S3_BUCKET_ARN
         :param bucket_environment_variable_name: Optional Name for the container environment variable set to the bucket name. Default: - S3_BUCKET_NAME
         :param bucket_permissions: Optional bucket permissions to grant to the Fargate service. One or more of the following may be specified: "Delete", "Read", "Write". Default: - [ "Read", "Write" ]
@@ -360,37 +336,15 @@ class FargateToS3Props:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An S3 Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**bucket_props)
         if isinstance(cluster_props, dict):
-            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
+            cluster_props = _aws_cdk_aws_ecs_ceddda9d.ClusterProps(**cluster_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**logging_bucket_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                bucket_environment_variable_name: typing.Optional[builtins.str] = None,
-                bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__de7859e1584efc89c48def3de03bef8b0c548e863c0a65cbee03184357fddbe8)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument bucket_arn_environment_variable_name", value=bucket_arn_environment_variable_name, expected_type=type_hints["bucket_arn_environment_variable_name"])
             check_type(argname="argument bucket_environment_variable_name", value=bucket_environment_variable_name, expected_type=type_hints["bucket_environment_variable_name"])
@@ -409,7 +363,7 @@ class FargateToS3Props:
             check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
             check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "public_api": public_api,
         }
         if bucket_arn_environment_variable_name is not None:
@@ -453,8 +407,6 @@ class FargateToS3Props:
 
         This has implications for the VPC deployed
         by this construct.
-
-        :default: - none
         '''
         result = self._values.get("public_api")
         assert result is not None, "Required property 'public_api' is missing"
@@ -490,19 +442,19 @@ class FargateToS3Props:
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def bucket_props(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
-    def cluster_props(self) -> typing.Optional[aws_cdk.aws_ecs.ClusterProps]:
+    def cluster_props(self) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps]:
         '''Optional properties to create a new ECS cluster.'''
         result = self._values.get("cluster_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ClusterProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps], result)
 
     @builtins.property
     def container_definition_props(self) -> typing.Any:
@@ -529,25 +481,25 @@ class FargateToS3Props:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def existing_bucket_obj(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_bucket_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     @builtins.property
     def existing_container_definition_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.ContainerDefinition]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition]:
         result = self._values.get("existing_container_definition_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ContainerDefinition], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition], result)
 
     @builtins.property
     def existing_fargate_service_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.FargateService]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService]:
         '''A Fargate Service already instantiated (probably by another Solutions Construct).
 
         If
@@ -559,10 +511,10 @@ class FargateToS3Props:
         :default: - none
         '''
         result = self._values.get("existing_fargate_service_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.FargateService], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC in which to deploy the construct.
 
         Providing both this and
@@ -573,7 +525,7 @@ class FargateToS3Props:
         :default: - none
         '''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def fargate_service_props(self) -> typing.Any:
@@ -590,13 +542,15 @@ class FargateToS3Props:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def logging_bucket_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
@@ -610,7 +564,7 @@ class FargateToS3Props:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Optional custom properties for a VPC the construct will create.
 
         This VPC will
@@ -622,7 +576,7 @@ class FargateToS3Props:
         :default: - none
         '''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -642,3 +596,53 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__5a872e0ea19151374d44819836b5422ed13b1d3eaaf460a209a1f9a4e784e646(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    public_api: builtins.bool,
+    bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    bucket_environment_variable_name: typing.Optional[builtins.str] = None,
+    bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__de7859e1584efc89c48def3de03bef8b0c548e863c0a65cbee03184357fddbe8(
+    *,
+    public_api: builtins.bool,
+    bucket_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    bucket_environment_variable_name: typing.Optional[builtins.str] = None,
+    bucket_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
